API docs for “spamfighter.core.test.test_log.MessageLogTestCase”

# Class s.c.t.t.MessageLogTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_log View Source View In Hierarchy

Тест на `spamfighter.core.log.MessageLog`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testInterface | Undocumented
Method | testPutFetch | Undocumented
Method | testPutFetchLong | Undocumented
Method | testFirst | Undocumented
Method | testLast | Undocumented
Method | testFirstLast | Undocumented
Method | testFirstWithShift | Undocumented
Method | testFirstID | Undocumented
Method | testPickling | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testPutFetch(self): (source)
Undocumented
def testPutFetchLong(self): (source)
Undocumented
def testFirst(self): (source)
Undocumented
def testLast(self): (source)
Undocumented
def testFirstLast(self): (source)
Undocumented
def testFirstWithShift(self): (source)
Undocumented
def testFirstID(self): (source)
Undocumented
def testPickling(self): (source)
Undocumented